@@ -1,3 +1,4 @@
+use std::env;
 use std::time::Duration;
 
 use cloudflare::framework::async_api;
@@ -12,17 +13,34 @@ use crate::http::{feature::headers, DEFAULT_HTTP_TIMEOUT_SECONDS};
 use crate::settings::global_user::GlobalUser;
 use crate::terminal::emoji;
 use crate::terminal::message::{Message, StdOut};
+
+const CF_API_BASE_URL: &str = "CF_API_BASE_URL";
+
+// Allow endpoint to be configured via an environment variable
+pub fn get_environment() -> Result<Environment> {
+    let env_hostname = match env::var(CF_API_BASE_URL) {
+        Ok(value) => {
+            if let Ok(url) = url::Url::parse(&value) {
+                url
+            } else {
+                anyhow::bail!("Failed to parse URL from environment variable. Please make sure your API endpoint URL is valid.")
+            }
+        }
+        Err(_) => return Ok(Environment::Production),
+    };
+
+    Ok(Environment::Custom(env_hostname))
+}
+
 pub fn cf_v4_client(user: &GlobalUser) -> Result<HttpApiClient> {
     let config = HttpApiClientConfig {
         http_timeout: Duration::from_secs(DEFAULT_HTTP_TIMEOUT_SECONDS),
         default_headers: headers(None),
     };
 
-    HttpApiClient::new(
-        Credentials::from(user.to_owned()),
-        config,
-        Environment::Production,
-    )
+    let environment = get_environment()?;
+
+    HttpApiClient::new(Credentials::from(user.to_owned()), config, environment)
 }
 
 pub fn cf_v4_api_client_async(user: &GlobalUser) -> Result<async_api::Client> {
@@ -31,11 +49,9 @@ pub fn cf_v4_api_client_async(user: &GlobalUser) -> Result<async_api::Client> {
         default_headers: headers(None),
     };
 
-    async_api::Client::new(
-        Credentials::from(user.to_owned()),
-        config,
-        Environment::Production,
-    )
+    let environment = get_environment()?;
+
+    async_api::Client::new(Credentials::from(user.to_owned()), config, environment)
 }
 
 // Format errors from the cloudflare-rs cli for printing.
@@ -74,3 +90,45 @@ fn print_status_code_context(status_code: StatusCode) {
       _ => (),
   }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn gets_environment_tests() {
+        // Tests are run in parallel, so dividing these three tests can lead
+        // to an undesired interleaving in set and unset of the environment variables.
+
+        // Test #1
+        // Tests that the API endpoint base URL can be read from an environment variable
+        let url = "https://github.com/cloudflare/wrangler";
+
+        env::set_var(CF_API_BASE_URL, url);
+        let test_environment_url = url::Url::from(&get_environment().unwrap());
+
+        let expected_environment_url = url::Url::parse(url).unwrap();
+        assert_eq!(test_environment_url, expected_environment_url);
+        env::remove_var(CF_API_BASE_URL);
+
+        // Test #2
+        // Tests that it fails with an invalid url
+        let url = "thisisaninvalidurl";
+
+        env::set_var(CF_API_BASE_URL, url);
+        let test_environment = get_environment();
+
+        assert!(test_environment.is_err());
+        env::remove_var(CF_API_BASE_URL);
+
+        // Test #3
+        // Tests that the API endpoint base URL is set to production if no environment variable is set
+
+        // unset the environment variable
+        env::remove_var(CF_API_BASE_URL);
+        let test_environment_url = url::Url::from(&get_environment().unwrap());
+
+        let expected_environment_url = url::Url::from(&Environment::Production);
+        assert_eq!(test_environment_url, expected_environment_url);
+    }
+}
