@@ -7,13 +7,12 @@ mod manifest;
 pub mod migrations;
 mod route;
 mod site;
-mod target;
+pub(crate) mod target;
 mod target_type;
 mod triggers;
 
-pub use builder::{Builder, ModuleRule, UploadFormat};
+pub use builder::{ModuleRule, UploadFormat};
 pub use durable_objects::{DurableObjects, DurableObjectsClass};
-pub use environment::Environment;
 pub use kv_namespace::{ConfigKvNamespace, KvNamespace};
 pub use manifest::Manifest;
 pub use route::{Route, RouteConfig};
